package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.KeyPo;
import com.caimei365.commodity.model.vo.CmProductArchiveVO;
import com.caimei365.commodity.service.CmProductArchiveContentService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 功能描述:内容库相关
 *
 * @auther: Kaick
 * @date: 2023/12/25 10:21
 * @params:
 * @return:
 */
@Api(tags = "内容库API")
@RestController
@RequestMapping("/commodity/product/archive")
public class ProductArchiveApi {

    @Resource
    private CmProductArchiveContentService cmProductArchiveContentService;


    @ApiOperation("商品资料列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/list")
    public ResponseJson list(@RequestParam(required=false)String title,
                             String userId,
                             @RequestParam(required=false)String type,
                             @RequestParam(required=false)Integer productId,
                             @RequestParam(required=false)Integer stageStatus,
                             @RequestParam(required=false)Integer allStatus,
                             @RequestParam(required=false)String labelIds,
                             Integer spId,
                             @RequestParam(value = "pageNum", defaultValue = "1") int pageNum) {

        List list = new ArrayList();
        pageNum = (pageNum - 1) * 5;
        if (StringUtils.isBlank(type)) {
            for (int i = 1; i <= 5; i++) {
                list.addAll(cmProductArchiveContentService.getCmProductArchiveContentList(new CmProductArchiveVO()
                        .setTitle(title)
                        .setUserId(userId)
                        .setType(String.valueOf(i))
                        .setProductId(productId)
                        .setStageStatus(stageStatus)
                        .setAllStatus(allStatus)
                        .setLabelIds(labelIds)
                        .setSpId(spId)
                        .setPageNum(0)));
            }
            list.addAll(cmProductArchiveContentService.getCmProductArchiveInfoList(0, title, labelIds));
            list.addAll(cmProductArchiveContentService.getCmProductArchiveBaikeList(0, title, labelIds));
        } else if ("6".equals(type)) {
            list.addAll(cmProductArchiveContentService.getCmProductArchiveInfoList(pageNum, title, labelIds));
        } else if ("7".equals(type)) {
            list.addAll(cmProductArchiveContentService.getCmProductArchiveBaikeList(pageNum, title, labelIds));
        } else {
            list.addAll(cmProductArchiveContentService.getCmProductArchiveContentList(new CmProductArchiveVO()
                    .setTitle(title)
                    .setUserId(userId)
                    .setType(type)
                    .setProductId(productId)
                    .setStageStatus(stageStatus)
                    .setAllStatus(allStatus)
                    .setLabelIds(labelIds)
                    .setSpId(spId)
                    .setPageNum(pageNum)));
        }
        return ResponseJson.success(list);
    }

    @GetMapping("/from")
    public ResponseJson from(String id, String userId) {

        CmProductArchiveVO archiveContent = cmProductArchiveContentService.getByCmProductArchiveContent(new CmProductArchiveVO()
                .setId(id)
                .setUserId(userId)
        );
        return ResponseJson.success(archiveContent);
    }

    @PostMapping("/add")
    public ResponseJson add(CmProductArchiveVO cmProductArchiveVO) {
        cmProductArchiveVO.setAllStatus(2);
        cmProductArchiveVO.setType("5");
        cmProductArchiveContentService.addCmProductArchiveContent(cmProductArchiveVO);
        return ResponseJson.success();
    }

    @GetMapping("/findKeyWordList")
    public ResponseJson findKeyWordList(String v,
                                        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                        @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<KeyPo> keyList = cmProductArchiveContentService.findKeyWordList(v);
        return ResponseJson.success(new PageInfo(keyList));
    }

    @GetMapping("/findProductList")
    public ResponseJson findProductList(String productName,
                                        String shopName,
                                        Integer productId,
                                        @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                        @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmProductArchiveVO> list = cmProductArchiveContentService.findProductList(new CmProductArchiveVO()
                .setProductId(productId)
                .setProductName(productName)
                .setShopName(shopName)
        );
        return ResponseJson.success(new PageInfo<>(list));
    }

    @GetMapping("/{userId}/{type}/{id}/details")
    public ResponseJson details(@PathVariable String id,
                                @PathVariable String type,
                                @PathVariable String userId) {

        if (StringUtils.isBlank(id)||
                StringUtils.isBlank(type)||
                StringUtils.isBlank(userId)) {
            ResponseJson.error("权限异常！");
        }

        CmProductArchiveVO archiveContent = cmProductArchiveContentService.getByCmProductArchiveContent(new CmProductArchiveVO()
                .setId(id)
                .setType(type)
                .setUserId(userId)
        );
        return ResponseJson.success(archiveContent);
    }

}
