package com.caimei365.commodity.controller;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.search.ProductListVo;
import com.caimei365.commodity.model.vo.PaginationVo;
import com.caimei365.commodity.model.vo.ProductShoplVo;
import com.caimei365.commodity.service.ShopOrderService;
import com.caimei365.commodity.service.ShopService;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/9/28
 */
@RestController
@RequestMapping("/commodity/Shop")
public class ShopApi {

    @Autowired private ShopOrderService shopOrderService;

    @Resource private ShopService shopService;

    /**
     * 供应商商品数据
     * @param shopId
     * @param name
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/getShopProduct")
    public ResponseJson<PaginationVo<ProductShoplVo>> getShopProductList(Integer shopId, String name, Integer pageNum, Integer pageSize) {
        if (null == shopId) {
            return ResponseJson.error(-1, "供应商Id不能为空", null);
        }
        return shopOrderService.getShopProductList(shopId, name, pageNum, pageSize);
    }

    /**
     * 供应商-主推商品
     */
    @ApiOperation("供应商主页--产品展示")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "shopId", value = "供应商Id"),
            @ApiImplicitParam(required = false, name = "categoryId", value = "供应商商品分类Id")
    })
    @GetMapping("/getCategoryProducts")
    public ResponseJson<List<ProductListVo>> getCategoryProducts(Integer shopId, Integer categoryId) {
        if (null == shopId) {
            return ResponseJson.error(-1, "供应商Id不能为空", null);
        }
        return shopService.getCategoryProducts(shopId, categoryId);
    }
}
