package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.CmDistributionProduct;
import com.caimei365.commodity.model.po.CmDistributionTeamProduct;
import com.caimei365.commodity.model.vo.ArchiveVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Mapper接口
 *
 * @author Kaick
 * @date 2023-09-18
 */
@Mapper
public interface CmDistributionProductMapper
{
    /**
     * 通过对象查询列表
     *
     * @param cmDistributionProduct
     * @return 集合
     */
    public List<CmDistributionProduct> getCmDistributionProductList(CmDistributionProduct cmDistributionProduct);
    /**
     * 通过对象查询列表
     *
     * @param cmDistributionTeamProduct
     * @return 集合
     */
    public List<CmDistributionTeamProduct> getCmDistributionTeamProductList(CmDistributionTeamProduct cmDistributionTeamProduct);

    /**
     * 查询分销商品资料列表
     *
     * @param productName     搜索关键词
     * @return
     */
    List<ArchiveVo> getProductArchiveList( @Param("id") Integer id,@Param("productName") String productName);

    /**
     * 通过对象查询分销团队商品列表
     *
     * @param cmDistributionProduct
     * @return 集合
     */
    public List<CmDistributionProduct> findTeamProductPage(CmDistributionProduct cmDistributionProduct);

    /**
     * 通过Id查询对象
     *
     * @param id 主键
     * @return
     */
    public CmDistributionProduct getCmDistributionProductById(String id);

    /**
     * 通过对象查询对象
     *
     * @param cmDistributionProduct
     * @return
     */
    public CmDistributionProduct getByCmDistributionProduct(CmDistributionProduct cmDistributionProduct);

    /**
     * 通过对象查询Id
     *
     * @param cmDistributionProduct
     * @return String
     */
    public String getById(CmDistributionProduct cmDistributionProduct);

    /**
     * 通过对象查询Ids
     *
     * @param cmDistributionProduct
     * @return List<String>
     */
    public List<String> getByIds(CmDistributionProduct cmDistributionProduct);
    /**
     * 通过对象查询商品Ids
     *
     * @param cmDistributionProduct
     * @return List<String>
     */
    public List<Integer> getByProductIds(CmDistributionProduct cmDistributionProduct);

    /**
     * 通过对象查询分销团队商品Ids
     *
     * @param cmDistributionProduct
     * @return List<String>
     */
    public List<Integer> getByTeamProductIds(CmDistributionProduct cmDistributionProduct);

    /**
     * 通过对象查询记录总数
     *
     * @param cmDistributionProduct
     * @return Integer
     */
    public int getCmDistributionProductCount(CmDistributionProduct cmDistributionProduct);

    /**
     * 通过对象查询记录总数
     *
     * @param cmDistributionTeamProduct
     * @return Integer
     */
    public int getCmDistributionTeamProductCount(CmDistributionTeamProduct cmDistributionTeamProduct);
    /**
     * 新增
     *
     * @param cmDistributionProduct
     * @return 结果
     */
    public int addCmDistributionProduct(CmDistributionProduct cmDistributionProduct);
    /**
     * 新增
     *
     * @param cmDistributionTeamProduct
     * @return 结果
     */
    public int addCmDistributionTeamProduct(CmDistributionTeamProduct cmDistributionTeamProduct);
    /**
     * 修改
     *
     * @param cmDistributionProduct
     * @return 结果
     */
    public int updateCmDistributionProduct(CmDistributionProduct cmDistributionProduct);



    /**
     * 批量删除
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmDistributionProduct(CmDistributionProduct cmDistributionProduct);

    /**
     * 批量删除
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmDistributionProductByIds(@Param("ids") String[] ids);



    /**
     * 修改
     *
     * @param cmDistributionTeamProduct
     * @return 结果
     */
    public int updateCmDistributionTeamProduct(CmDistributionTeamProduct cmDistributionTeamProduct);


    /**
     * 批量删除
     * @return 结果
     */
    public int delCmDistributionTeamProduct(CmDistributionTeamProduct cmDistributionTeamProduct);
}
