package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.CmPraiseStatistics;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 浏览量Mapper接口
 *
 * @author Kaick
 * @date 2023-08-15
 */
@Mapper
public interface CmPraiseStatisticsMapper
{
    /**
     * 通过对象查询浏览量列表
     *
     * @param cmPraiseStatistics 浏览量
     * @return 浏览量集合
     */
    public List<CmPraiseStatistics> getCmPraiseStatisticsList(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 通过Id查询浏览量对象
     *
     * @param id 浏览量主键
     * @return 浏览量
     */
    public CmPraiseStatistics getCmPraiseStatisticsById(String id);

    /**
     * 通过对象查询浏览量对象
     *
     * @param cmPraiseStatistics 浏览量
     * @return 浏览量
     */
    public CmPraiseStatistics getByCmPraiseStatistics(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 通过对象查询浏览量Id
     *
     * @param cmPraiseStatistics 浏览量
     * @return String
     */
    public String getById(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 通过对象查询浏览量Ids
     *
     * @param cmPraiseStatistics 浏览量
     * @return List<String>
     */
    public List<String> getByIds(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 通过对象查询浏览量记录总数
     *
     * @param cmPraiseStatistics 浏览量
     * @return 浏览量Integer
     */
    public int getCmPraiseStatisticsCount(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 新增浏览量
     *
     * @param cmPraiseStatistics 浏览量
     * @return 结果
     */
    public int addCmPraiseStatistics(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 修改浏览量
     *
     * @param cmPraiseStatistics 浏览量
     * @return 结果
     */
    public int updateCmPraiseStatistics(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 删除浏览量
     *
     * @param id 浏览量主键
     * @return 结果
     */
    public int delCmPraiseStatisticsById(String id);

    /**
     * 批量删除浏览量
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmPraiseStatistics(CmPraiseStatistics cmPraiseStatistics);

    /**
     * 批量删除浏览量
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmPraiseStatisticsByIds(@Param("ids") String[] ids);

    /**
     * 修改批量删除浏览量
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int updateDelCmPraiseStatisticsByIds(@Param("ids") String[] ids,@Param("delFlag") Integer delFlag);
}
