package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.CmRelatedImage;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 相关图片Mapper接口
 *
 * @author Kaick
 * @date 2023-09-20
 */
@Mapper
public interface CmRelatedImageMapper
{
    /**
     * 通过对象查询相关图片列表
     *
     * @param cmRelatedImage 相关图片
     * @return 相关图片集合
     */
    public List<CmRelatedImage> getCmRelatedImageList(CmRelatedImage cmRelatedImage);

    /**
     * 通过Id查询相关图片对象
     *
     * @param id 相关图片主键
     * @return 相关图片
     */
    public CmRelatedImage getCmRelatedImageById(String id);

    /**
     * 通过对象查询相关图片对象
     *
     * @param cmRelatedImage 相关图片
     * @return 相关图片
     */
    public CmRelatedImage getByCmRelatedImage(CmRelatedImage cmRelatedImage);

    /**
     * 通过对象查询相关图片Id
     *
     * @param cmRelatedImage 相关图片
     * @return String
     */
    public String getById(CmRelatedImage cmRelatedImage);

    /**
     * 通过对象查询相关图片Ids
     *
     * @param cmRelatedImage 相关图片
     * @return List<String>
     */
    public List<String> getByIds(CmRelatedImage cmRelatedImage);

    /**
     * 通过对象查询相关图片记录总数
     *
     * @param cmRelatedImage 相关图片
     * @return 相关图片Integer
     */
    public int getCmRelatedImageCount(CmRelatedImage cmRelatedImage);

    /**
     * 新增相关图片
     *
     * @param cmRelatedImage 相关图片
     * @return 结果
     */
    public int addCmRelatedImage(CmRelatedImage cmRelatedImage);

    /**
     * 修改相关图片
     *
     * @param cmRelatedImage 相关图片
     * @return 结果
     */
    public int updateCmRelatedImage(CmRelatedImage cmRelatedImage);

    /**
     * 删除相关图片
     *
     * @param id 相关图片主键
     * @return 结果
     */
    public int delCmRelatedImageById(String id);

    /**
     * 批量删除相关图片
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmRelatedImage(CmRelatedImage cmRelatedImage);

    /**
     * 批量删除相关图片
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmRelatedImageByIds(@Param("ids") String[] ids);

    /**
     * 修改批量删除相关图片
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int updateDelCmRelatedImageByIds(@Param("ids") String[] ids,@Param("delFlag") Integer delFlag);
}
