package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.CmReportingClub;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 机构报备Mapper接口
 *
 * @author Kaick
 * @date 2023-09-20
 */
@Mapper
public interface CmReportingClubMapper
{
    /**
     * 通过对象查询机构报备列表
     *
     * @param cmReportingClub 机构报备
     * @return 机构报备集合
     */
    public List<CmReportingClub> getCmReportingClubList(CmReportingClub cmReportingClub);

    /**
     * 通过Id查询机构报备对象
     *
     * @param id 机构报备主键
     * @return 机构报备
     */
    public CmReportingClub getCmReportingClubById(String id);

    /**
     * 通过对象查询机构报备对象
     *
     * @param cmReportingClub 机构报备
     * @return 机构报备
     */
    public CmReportingClub getByCmReportingClub(CmReportingClub cmReportingClub);

    /**
     * 通过对象查询机构报备Id
     *
     * @param cmReportingClub 机构报备
     * @return String
     */
    public String getById(CmReportingClub cmReportingClub);


    /**
     * 通过对象查询机构报备Ids
     *
     * @param cmReportingClub 机构报备
     * @return List<String>
     */
    public List<String> getByIds(CmReportingClub cmReportingClub);

    /**
     * 通过对象查询机构报备记录总数
     *
     * @param cmReportingClub 机构报备
     * @return 机构报备Integer
     */
    public int getCmReportingClubCount(CmReportingClub cmReportingClub);

    int findUserByMobile(@Param("mobile") String mobile, @Param("oldUserId") Integer oldUserId, @Param("userIdentity") Integer userIdentity);

    /**
     * 新增机构报备
     *
     * @param cmReportingClub 机构报备
     * @return 结果
     */
    public int addCmReportingClub(CmReportingClub cmReportingClub);

    /**
     * 修改机构报备
     *
     * @param cmReportingClub 机构报备
     * @return 结果
     */
    public int updateCmReportingClub(CmReportingClub cmReportingClub);

    /**
     * 删除机构报备
     *
     * @param id 机构报备主键
     * @return 结果
     */
    public int delCmReportingClubById(String id);

    /**
     * 批量删除机构报备
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmReportingClub(CmReportingClub cmReportingClub);

    /**
     * 批量删除机构报备
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmReportingClubByIds(@Param("ids") String[] ids);

    /**
     * 修改批量删除机构报备
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int updateDelCmReportingClubByIds(@Param("ids") String[] ids,@Param("delFlag") Integer delFlag);
}
