package com.caimei365.commodity.mapper;

import com.caimei365.commodity.model.po.CmDistribution;
import com.caimei365.commodity.model.po.CmReportingMember;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * 分销报备成员Mapper接口
 *
 * @author Kaick
 * @date 2023-09-20
 */
@Mapper
public interface CmReportingMemberMapper
{
    /**
     * 通过对象查询分销报备成员列表
     *
     * @param cmReportingMember 分销报备成员
     * @return 分销报备成员集合
     */
    public List<CmReportingMember> getCmReportingMemberList(CmReportingMember cmReportingMember);
    /**
     * 通过对象查询分销报备成员列表
     *
     * @param cmDistribution 分销报备成员
     * @return 分销报备成员集合
     */
    public List<CmReportingMember> getCmDistributionMemberList(@Param("cmDistribution")CmDistribution cmDistribution,@Param("clubName") String clubName,@Param("settleStatus") Integer settleStatus,@Param("payWay") Integer payWay,@Param("splitSettleStatus") Integer splitSettleStatus,@Param("shopOrderNo") String shopOrderNo,@Param("startTime") String startTime,@Param("endTime") String endTime);

    /**
     * 通过Id查询分销报备成员对象
     *
     * @param id 分销报备成员主键
     * @return 分销报备成员
     */
    public CmReportingMember getCmReportingMemberById(String id);

    /**
     * 通过对象查询分销报备成员对象
     *
     * @param cmReportingMember 分销报备成员
     * @return 分销报备成员
     */
    public CmReportingMember getByCmReportingMember(CmReportingMember cmReportingMember);

    /**
     * 通过对象查询分销报备成员Id
     *
     * @param cmReportingMember 分销报备成员
     * @return String
     */
    public String getById(CmReportingMember cmReportingMember);

    /**
     * 通过对象查询分销报备成员Ids
     *
     * @param cmReportingMember 分销报备成员
     * @return List<String>
     */
    public List<String> getByIds(CmReportingMember cmReportingMember);

    /**
     * 通过对象查询分销报备成员记录总数
     */
    public Integer getCount(CmReportingMember cmReportingMember);

    /**
     * 通过对象查询分销报备成员记录总数
     *
     * @return 分销报备成员Integer
     */
    public  Integer getCmReportingMemberCount(@Param("distributionId") String distributionId,@Param("parentId") Integer parentId,@Param("linkMan") String linkMan,@Param("mobile") String mobile,@Param("settleStatus") Integer settleStatus);

    /**
     * 通过对象查询分销报备佣金
     *
     * @return 分销报备成员Integer
     */
    public  BigDecimal getCmReportingMemberCommission(@Param("distributionId") String distributionId, @Param("parentId") Integer parentId, @Param("linkMan") String linkMan, @Param("mobile") String mobile, @Param("settleStatus") Integer settleStatus);
    /**
     * 通过对象查询分销订单佣金
     *
     * @return 分销报备成员Integer
     */
    public  BigDecimal getCmReportingMemberSplitCommission(@Param("distributionId") String distributionId, @Param("parentId") Integer parentId, @Param("linkMan") String linkMan, @Param("mobile") String mobile, @Param("splitSettleStatus") Integer settleStatus,@Param("payWay") Integer payWay,@Param("orderID") Integer orderID);
    /**
     * 通过对象查询分销订单记录总数
     *
     * @return 分销报备成员Integer
     */
    public  Integer getCmReportingMemberSplitCount(@Param("distributionId") String distributionId, @Param("parentId") Integer parentId, @Param("linkMan") String linkMan, @Param("mobile") String mobile, @Param("splitSettleStatus") Integer settleStatus,@Param("payWay") Integer payWay);

    /**
     * 新增分销报备成员
     *
     * @param cmReportingMember 分销报备成员
     * @return 结果
     */
    public int addCmReportingMember(CmReportingMember cmReportingMember);

    /**
     * 修改分销报备成员
     *
     * @param cmReportingMember 分销报备成员
     * @return 结果
     */
    public int updateCmReportingMember(CmReportingMember cmReportingMember);

    /**
     * 删除分销报备成员
     *
     * @param id 分销报备成员主键
     * @return 结果
     */
    public int delCmReportingMemberById(String id);

    /**
     * 批量删除分销报备成员
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmReportingMember(CmReportingMember cmReportingMember);

    /**
     * 批量删除分销报备成员
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int delCmReportingMemberByIds(@Param("ids") String[] ids);

    /**
     * 修改批量删除分销报备成员
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int updateDelCmReportingMemberByIds(@Param("ids") String[] ids,@Param("delFlag") Integer delFlag);
}
