package com.caimei365.commodity.model.vo;

import com.caimei365.commodity.utils.AesEncryptUtil;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.Data;
import lombok.experimental.Accessors;
import org.apache.ibatis.type.Alias;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 商品资料库对象 cm_product_archive VO对象
 *
 * @author Kaick
 * @date 2023-12-25
 */
@Accessors(chain = true)
@Data
@Alias("CmProductArchiveVO")
public class CmProductArchiveVO implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 商品资料库id
     */
    private Integer productArchiveId;

    /**
     * id
     */
    private String id;
    /**
     * userId
     */
    private String userId;
    /**
     * permission:0可查看，1未登录，2需升级会员机构(已弃用)，3需升级医美会员机构，4需要抵扣采美豆(已弃用)，5无权限查看
     */
    private Integer permission;

    /**
     * 商品id
     */
    private Integer productId;

    /**
     * 商品名称
     */
    private String productName;

    /**
     * 供应商名称
     */
    private String shopName;

    /**
     * 商品图片
     */
    private String image;

    /**
     * 商品属性：1产品，2仪器
     */
    private String productType;

    /**
     * 商品分类：1医美，2生美
     */
    private Integer productClassify;

    /**
     * 添加时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date addTime;

    /**
     * 标签库ids
     */
    private String labelIds;
    /**
     * 标签库s
     */
    private String keywords;


    /**
     * 资料标题
     */
    private String title;

    /**
     * 资料类型：
     * 1图片资料，
     * 2视频资料，
     * 3文件资料，
     * 4文本资料
     * 5话术资料
     */
    private String type;

    /**
     * 内容
     */
    private String content;

    /**
     * 用户阶段状态：
     * 1认知阶段、
     * 2兴趣阶段、
     * 3决策阶段、
     * 4购买阶段
     */
    private Integer stageStatus;

    /**
     * 所有状态：
     * 1企业，
     * 2个人
     */
    private Integer allStatus;
    /**
     * 协销Id
     */
    private Integer spId;
    /**
     * createBy
     */
    private String createBy;
    /**
     * 点击量
     */
    private Integer pv;

    private Integer pageNum;

    /**
     * 水印oss链接
     */
    private List<String> waters;

    public CmProductArchiveVO setWaters(List<String> waters) {
        List<String> strings = new ArrayList(waters.size());
        if (waters != null) {
            waters.forEach(s -> {
                strings.add(AesEncryptUtil.encrypt(s));
            });
        }
        this.waters = strings;
        return this;
    }
}
