package com.caimei365.commodity.service;

import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.CmDistribution;
import com.caimei365.commodity.model.po.CmDistributionTeamProduct;
import com.caimei365.commodity.model.po.CmReportingClub;
import com.caimei365.commodity.model.po.CmReportingMember;
import com.caimei365.commodity.model.vo.ArchiveVo;

import java.math.BigDecimal;
import java.util.List;

/**
 * 机构报备Service接口
 *
 * @author Kaick
 * @date 2023-09-26
 */
public interface CmReportingClubService {
    /**
     * 通过对象查询机构报备列表
     *
     * @param cmReportingClub 机构报备
     * @return 机构报备集合
     */
    public List<CmReportingMember> getCmReportingClubList(CmDistribution cmDistribution, String clubName, Integer settleStatus, Integer payWay, Integer splitSettleStatus, String shopOrderNo, String startTime, String entTime);

    /**
     * 功能描述: 分销团队商品列表
     *
     * @param cmDistribution
     * @return [cmDistribution]
     * @auther: Kaick
     * @date: 2023/9/26 13:39
     */

    public List<CmDistributionTeamProduct> getCmDistributionTeamProductList(CmDistribution cmDistribution);

    /**
     * 查询分销商品资料列表
     *
     * @param productName 搜索关键词
     * @return
     */
    List<ArchiveVo> getProductArchiveList(Integer id, String productName);

    /**
     * 通过Id查询机构报备
     *
     * @param id 机构报备主键
     * @return 机构报备
     */
    public CmReportingMember getCmReportingMemberById(String id);

    public CmDistribution getCmDistributionById(String id);

    public CmReportingClub getCmReportingClubById(String id);

    public List<CmDistribution> getCmDistributionList(CmDistribution cmDistribution);

    Integer getCount(CmReportingMember cmReportingMember);

    public Integer getCmReportingMemberCount(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus);

    public BigDecimal getCmReportingMemberCommission(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus);

    public Integer getCmReportingMemberSplitCount(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus, Integer payWay);

    public BigDecimal getCmReportingMemberSplitCommission(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus, Integer payWay,Integer orderID);

    public void updateCmReportingClub(CmReportingClub cmReportingClub);

    public void updateCmReportingMember(CmReportingMember cmReportingMember);

    /**
     * 新增机构报备
     */
    public ResponseJson addCmReportingClub(CmReportingClub cmReportingClub);

}


