package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.feign.UserFeign;
import com.caimei365.commodity.mapper.CmProductArchiveContentMapper;
import com.caimei365.commodity.mapper.PageMapper;
import com.caimei365.commodity.mapper.PriceMapper;
import com.caimei365.commodity.model.po.KeyPo;
import com.caimei365.commodity.model.vo.CmProductArchiveVO;
import com.caimei365.commodity.service.CmProductArchiveContentService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
 * 商品资料内容Service业务层处理
 *
 * @author Kaick
 * @date 2023-12-25
 */
@Service
public class CmProductArchiveContentServiceImpl implements CmProductArchiveContentService
{
    @Resource
    private PageMapper pageMapper;

    @Resource
    private PriceMapper priceMapper;
    @Resource
    private CmProductArchiveContentMapper cmProductArchiveContentMapper;
    @Resource
    private UserFeign userFeign;

    @Override
    public List<CmProductArchiveVO> getCmProductArchiveContentList(CmProductArchiveVO cmProductArchiveVO) {
        List<CmProductArchiveVO> cmProductArchiveContentList = cmProductArchiveContentMapper.getCmProductArchiveContentList(cmProductArchiveVO);
        if (cmProductArchiveContentList != null) {
            for (CmProductArchiveVO productArchiveVO : cmProductArchiveContentList) {
                productArchiveVO.setWaters(cmProductArchiveContentMapper.getProductArchiveFileList(productArchiveVO.getId()));
            }
        }
        return cmProductArchiveContentList;
    }

    @Override
    public List<CmProductArchiveVO> getCmProductArchiveInfoList(Integer pageNum,String title,String labelIds) {
        return cmProductArchiveContentMapper.getCmProductArchiveInfoList(pageNum, title, labelIds);
    }

    @Override
    public List<CmProductArchiveVO> getCmProductArchiveBaikeList(Integer pageNum,String title,String labelIds) {
        return cmProductArchiveContentMapper.getCmProductArchiveBaikeList(pageNum, title, labelIds);
    }

    @Override
    public List<KeyPo> findKeyWordList(String v) {
        return cmProductArchiveContentMapper.findKeyWordList(v);
    }

    @Override
    public List<CmProductArchiveVO> findProductList(CmProductArchiveVO cmProductArchiveVO) {
        return cmProductArchiveContentMapper.findProductList(cmProductArchiveVO);
    }

    @Override
    public CmProductArchiveVO getByCmProductArchiveContent(CmProductArchiveVO cmProductArchiveVO) {
        CmProductArchiveVO byCmProductArchiveContent = cmProductArchiveContentMapper.getByCmProductArchiveContent(cmProductArchiveVO);
        if (byCmProductArchiveContent != null) {
            int permission = checkArchivePermission(byCmProductArchiveContent.getProductClassify(), Integer.valueOf(cmProductArchiveVO.getUserId()));
            byCmProductArchiveContent.setPermission(permission);
            byCmProductArchiveContent.setWaters(cmProductArchiveContentMapper.getProductArchiveFileList(byCmProductArchiveContent.getId()));

        }
        return byCmProductArchiveContent;
    }

    @Override
    public int addCmProductArchiveContent(CmProductArchiveVO cmProductArchiveVO) {
       if(null!=cmProductArchiveVO.getId()){
           cmProductArchiveContentMapper.updateCmProductArchiveContent(cmProductArchiveVO);
       }else {
           cmProductArchiveVO.setAddTime(new Date());
           cmProductArchiveContentMapper.addCmProductArchiveContent(cmProductArchiveVO);
       }
        return 1;
    }


    @Override
    public int delCmProductArchiveContentById(String id) {
        return cmProductArchiveContentMapper.delCmProductArchiveContentById(id);
    }

    private Integer checkArchivePermission(Integer productClassify, Integer userId) {
        // 根据用户Id查询用户身份
        Integer identity = priceMapper.getIdentityByUserId(userId);
        // 1生美机构，2医美机构
        Integer clubType = pageMapper.getClubTypeByUserId(userId);
        // permission:0可查看，1未登录，2需升级会员机构(已弃用)，3需升级医美会员机构，4需要抵扣采美豆(已弃用)，5无权限查看
        int permission;
        if (null == identity) {
            // 未登录
            permission = 1;
        } else if (1 == identity  || 2 == clubType) {
            //协销和医美可查看所有资料
            permission = 0;
        } else if (2 != clubType) {
            //个人机构、医美、生美、项目公司、其他 仅可以访问生美资料
            permission = 1 == productClassify ? 3 : 0;
        } else {
            permission = 5;
        }
        return permission;
    }

}

