package com.caimei365.commodity.service.impl;

import com.caimei365.commodity.mapper.*;
import com.caimei365.commodity.model.ResponseJson;
import com.caimei365.commodity.model.po.*;
import com.caimei365.commodity.model.vo.ArchiveVo;
import com.caimei365.commodity.service.CmReportingClubService;
import com.caimei365.commodity.utils.MathUtil;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;
import java.util.List;

/**
 * 机构报备Service业务层处理
 *
 * @author Kaick
 * @date 2023-09-26
 */
@Service
public class CmReportingClubServiceImpl implements CmReportingClubService {
    @Resource
    private CmReportingClubMapper cmReportingClubMapper;
    @Resource
    private CmReportingMemberMapper cmReportingMemberMapper;
    @Resource
    private CmRelatedImageMapper cmRelatedImageMapper;
    @Resource
    private CmDistributionMapper cmDistributionMapper;
    @Resource
    private CmDistributionProductMapper cmDistributionProductMapper;

    /**
     * 通过对象查询机构报备列表
     *
     * @param cmDistribution 机构报备
     * @return 机构报备
     */
    @Override
    public List<CmReportingMember> getCmReportingClubList(CmDistribution cmDistribution, String clubName, Integer settleStatus, Integer payWay, Integer splitSettleStatus, String shopOrderNo, String startTime, String entTime) {
        List<CmReportingMember> cmReportingMemberList = cmReportingMemberMapper.getCmDistributionMemberList(cmDistribution, clubName, settleStatus, payWay, splitSettleStatus, shopOrderNo, startTime, entTime);
       if(cmReportingMemberList.size()>0){
           cmReportingMemberList.forEach(s -> {
               s.cmReportingClub(cmReportingClubMapper.getCmReportingClubById(String.valueOf(s.clubReportingId())));
               s.cmReportingClub().distributionProduct(cmDistributionProductMapper.getByCmDistributionProduct(new CmDistributionProduct().productId(s.cmReportingClub().productId())));
               s.cmReportingClub().distributionProduct().price(setDistributionProductPrice(s.cmReportingClub().productId()));
           });
       }

        return cmReportingMemberList;
    }

    /**
     * 通过对象查询分销团队商品列表
     *
     * @param cmDistribution 机构报备
     * @return 机构报备
     */
    @Override
    public List<CmDistributionTeamProduct> getCmDistributionTeamProductList(CmDistribution cmDistribution) {
        List<CmDistributionTeamProduct> cmDistributionTeamProductList = cmDistributionProductMapper.getCmDistributionTeamProductList(new CmDistributionTeamProduct().distributionId(Integer.valueOf(cmDistribution.id())));
        if(cmDistributionTeamProductList.size()>0) {
            cmDistributionTeamProductList.forEach(s -> {
                s.setPrice(setDistributionProductPrice(s.productId()));
            });
        }
        return cmDistributionTeamProductList;
    }

    @Override
    public List<ArchiveVo> getProductArchiveList(Integer id, String productName) {
        return cmDistributionProductMapper.getProductArchiveList(id, productName);
    }

    @Override
    public CmDistribution getCmDistributionById(String id) {
        return cmDistributionMapper.getCmDistributionById(id);
    }

    @Override
    public CmReportingClub getCmReportingClubById(String id) {
        return cmReportingClubMapper.getCmReportingClubById(id);
    }

    @Override
    public List<CmDistribution> getCmDistributionList(CmDistribution cmDistribution) {
        return cmDistributionMapper.getCmDistributionList(cmDistribution);
    }

    @Override
    public Integer getCount(CmReportingMember cmReportingMember) {
        Integer cmReportingMemberCount = cmReportingMemberMapper.getCount(cmReportingMember);
        return cmReportingMemberCount == null ? 0 : cmReportingMemberCount;
    }

    @Override
    public Integer getCmReportingMemberCount(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus) {
        Integer cmReportingMemberCount = cmReportingMemberMapper.getCmReportingMemberCount(distributionId, parentId, linkMan, mobile, settleStatus);
        return cmReportingMemberCount == null ? 0 : cmReportingMemberCount;
    }

    @Override
    public BigDecimal getCmReportingMemberCommission(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus) {
        BigDecimal cmReportingMemberCommission = cmReportingMemberMapper.getCmReportingMemberCommission(distributionId, parentId, linkMan, mobile, settleStatus);
        return cmReportingMemberCommission == null ? new BigDecimal(0) : cmReportingMemberCommission;
    }

    @Override
    public Integer getCmReportingMemberSplitCount(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus, Integer payWay) {
        Integer cmReportingMemberSplitCount = cmReportingMemberMapper.getCmReportingMemberSplitCount(distributionId, parentId, linkMan, mobile, settleStatus, payWay);
        return cmReportingMemberSplitCount == null ? 0 : cmReportingMemberSplitCount;
    }

    @Override
    public BigDecimal getCmReportingMemberSplitCommission(String distributionId, Integer parentId, String linkMan, String mobile, Integer settleStatus, Integer payWay,Integer orderID) {
        BigDecimal cmReportingMemberSplitCommission = cmReportingMemberMapper.getCmReportingMemberSplitCommission(distributionId, parentId, linkMan, mobile, settleStatus, payWay,orderID);
        return cmReportingMemberSplitCommission == null ? new BigDecimal(0) : cmReportingMemberSplitCommission;
    }

    /**
     * 通过Id查询机构报备
     *
     * @param id 机构报备主键
     * @return 机构报备
     */
    @Override
    public CmReportingMember getCmReportingMemberById(String id) {
        CmReportingMember cmReportingMemberById = cmReportingMemberMapper.getCmReportingMemberById(id);
        if (null != cmReportingMemberById) {
            cmReportingMemberById.cmReportingClub(cmReportingClubMapper.getCmReportingClubById(String.valueOf(cmReportingMemberById.clubReportingId())));
            //机构订单已报备人数
            Integer count = cmReportingMemberMapper.getCount(new CmReportingMember().clubReportingId(cmReportingMemberById.clubReportingId()).auditStatus("2"));
            cmReportingMemberById.cmReportingClub().distributionCount(count == null ? 0 : count);
            cmReportingMemberById.cmReportingClub().distributionProduct(cmDistributionProductMapper.getByCmDistributionProduct(new CmDistributionProduct().productId(cmReportingMemberById.cmReportingClub().productId())));
            cmReportingMemberById.cmRelatedImageList(cmRelatedImageMapper.getCmRelatedImageList(new CmRelatedImage().type("1").authorId(cmReportingMemberById.id())));
        }
        return cmReportingMemberById;
    }

    /**
     * 修改机构报备
     *
     * @return 机构报备
     */
    @Override
    public void updateCmReportingClub(CmReportingClub cmReportingClub) {
        cmReportingClubMapper.updateCmReportingClub(cmReportingClub);
    }

    /**
     * 修改机构报备
     *
     * @return 机构报备
     */
    @Override
    public void updateCmReportingMember(CmReportingMember cmReportingMember) {
        cmReportingMemberMapper.updateCmReportingMember(cmReportingMember);
    }

    /**
     * 新增机构报备
     */
    @Override
    public ResponseJson addCmReportingClub(CmReportingClub cmReportingClub) {
        int userByMobile = cmReportingClubMapper.findUserByMobile(cmReportingClub.mobile(), null, 8);
        if (userByMobile >0) {
            return ResponseJson.error("抱歉，该手机号已注册！");
        }
        CmReportingClub byCmReportingClub = cmReportingClubMapper.getByCmReportingClub(new CmReportingClub()
                .mobile(cmReportingClub.mobile())
                .productId(cmReportingClub.productId())
                .lockStatus(1)
        );
        if (null == byCmReportingClub) {
            byCmReportingClub = cmReportingClubMapper.getByCmReportingClub(new CmReportingClub()
                    .mobile(cmReportingClub.mobile())
                    .productId(cmReportingClub.productId())
                    .lockStatus(0)
            );
            if (null == byCmReportingClub) {
                cmReportingClub.lockStatus(0).createTime(new Date());
                cmReportingClubMapper.addCmReportingClub(cmReportingClub);
            }
            String byId = cmReportingClubMapper.getById(new CmReportingClub()
                    .mobile(cmReportingClub.mobile())
                    .productId(cmReportingClub.productId())
                    .lockStatus(0)
            );
            CmReportingMember cmReportingMember = cmReportingClub.cmReportingMember()
                    .clubReportingId(Integer.valueOf(byId));
            if(null!=cmReportingMemberMapper.getByCmReportingMember(cmReportingMember)){
                return ResponseJson.error("该机构您已报备，请勿重复报备！");
            }
            cmReportingMember.auditStatus("1").createTime(new Date());
            cmReportingMemberMapper.addCmReportingMember(cmReportingMember);
            if (null != cmReportingMember.cmRelatedImageList()) {
                cmReportingMember.cmRelatedImageList().forEach(s -> {
                    s.type("1");
                    s.authorId(cmReportingMember.id())
                            .createTime(new Date());
                    cmRelatedImageMapper.addCmRelatedImage(s);
                });
            }
            return ResponseJson.success("报备成功！", null);
        } else {
            return ResponseJson.error("抱歉，该机构已被其他人锁定，目前暂无法进行报备！");
        }
    }
    public BigDecimal setDistributionProductPrice(Integer productId) {
        CmDistributionProduct price = cmDistributionProductMapper.getByCmDistributionProduct(new CmDistributionProduct().productId(productId));
        boolean taxFlag = "0".equals(price.getIncludedTax()) && ("1".equals(price.getInvoiceType()) || "2".equals(price.getInvoiceType()));
        //添加税费
        if (taxFlag) {
            BigDecimal thisTaxFee = MathUtil.div(MathUtil.mul(price.getPrice(), price.getClubTaxPoint()), 100, 2);
            price.setPrice(MathUtil.add(price.getPrice(), thisTaxFee));
        }
        return price.getPrice().setScale(2, RoundingMode.HALF_UP);
    }
}


